@@ -747,94 +747,6 @@ class CrossContinJaccardMultiCoreCPU(AbstractCrossMetric):
         return np.max(full_crosscontinjaccards, axis=-1)
 
 
-class CrossContinJaccardMultiCoreCPU2(AbstractCrossMetric):
-
-    def __init__(self, n_cores, verbose=True):
-        self.n_cores = n_cores
-        self.verbose = verbose
-
-    def __call__(self, filters, things_to_scan, min_overlap):
-
-        from joblib import Parallel, delayed
-        if (self.verbose):
-            print("Begin cross contin jaccard")
-
-        assert len(filters.shape)==3,"Did you pass in filters of unequal len?"
-        assert len(things_to_scan.shape)==3
-        assert filters.shape[-1] == things_to_scan.shape[-1]
-
-        filter_length = filters.shape[1]
-        padding_amount = int((filter_length)*(1-min_overlap))
-        padded_input = np.array([np.pad(array=x,
-                              pad_width=((padding_amount, padding_amount),
-                                         (0,0)),
-                              mode="constant") for x in things_to_scan])
-
-        len_output = 1+padded_input.shape[1]-filters.shape[1]
-        full_crosscontinjaccards =\
-            np.zeros((filters.shape[0], padded_input.shape[0], len_output))
-
-        start = time.time()
-        #parallelize by index
-        job_arguments = []
-        for idx in range(0,len_output):
-            snapshot = padded_input[:,idx:idx+filters.shape[1],:]
-            assert snapshot.shape[1]==filters.shape[1],\
-                str(snapshot.shape)+" "+filters.shape
-            job_arguments.append((filters, snapshot))
-
-        to_concat = (Parallel(n_jobs=self.n_cores)
-                       (delayed(jaccard_sim_func)(job_args[0], job_args[1])
-                        for job_args in job_arguments))
-        full_crosscontinjaccards[:,:,:] =\
-                np.concatenate([x[:,:,None] for x in to_concat],axis=2)
-        end = time.time()
-        if (self.verbose):
-            print("Cross contin jaccard time taken:",round(end-start,2),"s")
-
-        return np.max(full_crosscontinjaccards, axis=-1)
-
-
-class CrossContinJaccardGPU(AbstractCrossMetric):
-
-    def __init__(self, verbose=True, batch_size=100):
-        self.verbose = verbose
-        self.batch_size = batch_size
-
-    def __call__(self, filters, things_to_scan, min_overlap):
-        assert len(filters.shape)==3,"Did you pass in filters of unequal len?"
-        assert len(things_to_scan.shape)==3
-        assert filters.shape[-1] == things_to_scan.shape[-1]
-        jaccard_sim_func = B.get_jaccard_sim_func(filters)
-
-        filter_length = filters.shape[1]
-        padding_amount = int((filter_length)*(1-min_overlap))
-        padded_input = np.array([np.pad(array=x,
-                              pad_width=((padding_amount, padding_amount),
-                                         (0,0)),
-                              mode="constant") for x in things_to_scan])
-
-        len_output = 1+padded_input.shape[1]-filters.shape[1]
-        full_crosscontinjaccard =\
-            np.zeros((filters.shape[0], padded_input.shape[0], len_output))
-
-        for idx in range(len_output):
-            if (self.verbose):
-                print("On offset",idx,"of",len_output-1)
-                sys.stdout.flush()
-            snapshot = padded_input[:,idx:idx+filters.shape[1],:]
-            batch_start = 0
-            while (batch_start < snapshot.shape[0]):
-                batch_end = min(batch_start+self.batch_size, snapshot.shape[0])
-                batch = snapshot[batch_start:batch_end]
-                sys.stdout.flush()
-                full_crosscontinjaccard[:,batch_start:batch_end,idx] =\
-                    jaccard_sim_func(batch) 
-                sys.stdout.flush()
-                batch_start += self.batch_size
-        return np.max(full_crosscontinjaccard, axis=-1) 
-
-
 class FilterSparseRows(object):
 
     def __init__(self, affmat_transformer,
